"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sort = exports.sortingElems = void 0;
const utils_1 = require("./utils");
const koelle_sort_1 = require("@cablanchard/koelle-sort");
/**
 * Determines the sort order of `sort`
 */
exports.sortingElems = [
    "building_number",
    "building_name",
    "sub_building_name",
    "organisation_name",
    "department_name",
    "po_box",
];
/**
 * Takes a `SortableAddress` and returns a building number, first checking for
 * name exceptions in building_name and sub_building_name fields
 */
const extractIntegerAttribute = (a) => {
    if ((0, utils_1.nameException)(a.building_name))
        return a.building_name;
    if ((0, utils_1.nameException)(a.sub_building_name))
        return a.sub_building_name;
    return a.building_number;
};
/**
 * Sorts addresses based on the precedence outlined in `sortingElems`
 */
const sort = (a, b) => {
    for (const attr of exports.sortingElems) {
        let A, B;
        if (attr === "building_number") {
            A = extractIntegerAttribute(a);
            B = extractIntegerAttribute(b);
        }
        else {
            A = a[attr];
            B = b[attr];
        }
        if (A === B)
            continue;
        return (0, koelle_sort_1.alphanum)(A, B);
    }
    return 0;
};
exports.sort = sort;
